@@ -17,7 +17,7 @@
 
 import base64
 import os
-from typing import BinaryIO, Dict, List, Optional, Union
+from typing import BinaryIO
 
 from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
 from selenium.webdriver.common.options import ArgOptions
@@ -27,49 +27,50 @@ class ChromiumOptions(ArgOptions):
     KEY = "goog:chromeOptions"
 
     def __init__(self) -> None:
+        """Initialize ChromiumOptions with default settings."""
         super().__init__()
         self._binary_location: str = ""
-        self._extension_files: List[str] = []
-        self._extensions: List[str] = []
-        self._experimental_options: Dict[str, Union[str, int, dict, List[str]]] = {}
-        self._debugger_address: Optional[str] = None
+        self._extension_files: list[str] = []
+        self._extensions: list[str] = []
+        self._experimental_options: dict[str, str | int | dict | list[str]] = {}
+        self._debugger_address: str | None = None
+        self._enable_webextensions: bool = False
 
     @property
     def binary_location(self) -> str:
-        """:Returns: The location of the binary, otherwise an empty string."""
+        """Returns the location of the binary, otherwise an empty string."""
         return self._binary_location
 
     @binary_location.setter
     def binary_location(self, value: str) -> None:
         """Allows you to set where the chromium binary lives.
 
-        :Args:
-         - value: path to the Chromium binary
+        Args:
+            value: Path to the Chromium binary.
         """
         if not isinstance(value, str):
             raise TypeError(self.BINARY_LOCATION_ERROR)
         self._binary_location = value
 
     @property
-    def debugger_address(self) -> Optional[str]:
-        """:Returns: The address of the remote devtools instance."""
+    def debugger_address(self) -> str | None:
+        """Returns the address of the remote devtools instance."""
         return self._debugger_address
 
     @debugger_address.setter
     def debugger_address(self, value: str) -> None:
-        """Allows you to set the address of the remote devtools instance that
-        the ChromeDriver instance will try to connect to during an active wait.
+        """Set the address of the remote devtools instance for active wait connection.
 
-        :Args:
-         - value: address of remote devtools instance if any (hostname[:port])
+        Args:
+            value: Address of remote devtools instance if any (hostname[:port]).
         """
         if not isinstance(value, str):
             raise TypeError("Debugger Address must be a string")
         self._debugger_address = value
 
     @property
-    def extensions(self) -> List[str]:
-        """:Returns: A list of encoded extensions that will be loaded."""
+    def extensions(self) -> list[str]:
+        """Returns a list of encoded extensions that will be loaded."""
 
         def _decode(file_data: BinaryIO) -> str:
             # Should not use base64.encodestring() which inserts newlines every
@@ -85,11 +86,10 @@ class ChromiumOptions(ArgOptions):
         return encoded_extensions + self._extensions
 
     def add_extension(self, extension: str) -> None:
-        """Adds the path to the extension to a list that will be used to
-        extract it to the ChromeDriver.
+        """Add the path to an extension to be extracted to ChromeDriver.
 
-        :Args:
-         - extension: path to the \\*.crx file
+        Args:
+            extension: Path to the *.crx file.
         """
         if extension:
             extension_to_add = os.path.abspath(os.path.expanduser(extension))
@@ -101,11 +101,10 @@ class ChromiumOptions(ArgOptions):
             raise ValueError("argument can not be null")
 
     def add_encoded_extension(self, extension: str) -> None:
-        """Adds Base64 encoded string with extension data to a list that will
-        be used to extract it to the ChromeDriver.
+        """Add Base64-encoded string with extension data to be extracted to ChromeDriver.
 
-        :Args:
-         - extension: Base64 encoded string with extension data
+        Args:
+            extension: Base64 encoded string with extension data.
         """
         if extension:
             self._extensions.append(extension)
@@ -114,21 +113,60 @@ class ChromiumOptions(ArgOptions):
 
     @property
     def experimental_options(self) -> dict:
-        """:Returns: A dictionary of experimental options for chromium."""
+        """Returns a dictionary of experimental options for chromium."""
         return self._experimental_options
 
-    def add_experimental_option(self, name: str, value: Union[str, int, dict, List[str]]) -> None:
+    def add_experimental_option(self, name: str, value: str | int | dict | list[str]) -> None:
         """Adds an experimental option which is passed to chromium.
 
-        :Args:
-          name: The experimental option name.
-          value: The option value.
+        Args:
+            name: The experimental option name.
+            value: The option value.
         """
         self._experimental_options[name] = value
 
+    @property
+    def enable_webextensions(self) -> bool:
+        """Return whether webextension support is enabled for Chromium-based browsers."""
+        return self._enable_webextensions
+
+    @enable_webextensions.setter
+    def enable_webextensions(self, value: bool) -> None:
+        """Enables or disables webextension support for Chromium-based browsers.
+
+        Args:
+            value: True to enable webextension support, False to disable.
+
+        Notes:
+            - When enabled, this automatically adds the required Chromium flags:
+                - --enable-unsafe-extension-debugging
+                - --remote-debugging-pipe
+            - When disabled, this removes BOTH flags listed above, even if they were manually added via add_argument()
+              before enabling webextensions.
+            - Enabling --remote-debugging-pipe makes the connection b/w chromedriver
+              and the browser use a pipe instead of a port, disabling many CDP functionalities
+              like devtools
+        """
+        self._enable_webextensions = value
+        if value:
+            # Add required flags for Chromium webextension support
+            required_flags = ["--enable-unsafe-extension-debugging", "--remote-debugging-pipe"]
+            for flag in required_flags:
+                if flag not in self._arguments:
+                    self.add_argument(flag)
+        else:
+            # Remove webextension flags if disabling
+            flags_to_remove = ["--enable-unsafe-extension-debugging", "--remote-debugging-pipe"]
+            for flag in flags_to_remove:
+                if flag in self._arguments:
+                    self._arguments.remove(flag)
+
     def to_capabilities(self) -> dict:
-        """Creates a capabilities with all the options that have been set
-        :Returns: A dictionary with everything."""
+        """Creates a capabilities with all the options that have been set.
+
+        Returns:
+            A dictionary with all set options.
+        """
         caps = self._caps
         chrome_options = self.experimental_options.copy()
         if self.mobile_options:
