@@ -15,9 +15,8 @@
 # specific language governing permissions and limitations
 # under the License.
 
-from typing import Optional
 
-from .account import Account
+from selenium.webdriver.common.fedcm.account import Account
 
 
 class Dialog:
@@ -30,7 +29,7 @@ class Dialog:
         self._driver = driver
 
     @property
-    def type(self) -> Optional[str]:
+    def type(self) -> str | None:
         """Gets the type of the dialog currently being shown."""
         return self._driver.fedcm.dialog_type
 
@@ -40,7 +39,7 @@ class Dialog:
         return self._driver.fedcm.title
 
     @property
-    def subtitle(self) -> Optional[str]:
+    def subtitle(self) -> str | None:
         """Gets the subtitle of the dialog."""
         result = self._driver.fedcm.subtitle
         return result.get("subtitle") if result else None
