@@ -15,7 +15,6 @@
 # specific language governing permissions and limitations
 # under the License.
 
-from typing import Optional
 
 from selenium.common.exceptions import WebDriverException
 from selenium.webdriver.common.driver_finder import DriverFinder
@@ -31,17 +30,16 @@ class WebDriver(RemoteWebDriver):
     def __init__(
         self,
         keep_alive=True,
-        options: Optional[Options] = None,
-        service: Optional[Service] = None,
+        options: Options | None = None,
+        service: Service | None = None,
     ) -> None:
-        """Creates a new Safari driver instance and launches or finds a running
-        safaridriver service.
+        """Create a new Safari driver instance and launch or find a running safaridriver service.
 
-        :Args:
-         - keep_alive - Whether to configure SafariRemoteConnection to use
-             HTTP keep-alive. Defaults to True.
-         - options - Instance of ``options.Options``.
-         - service - Service object for handling the browser driver if you need to pass extra details
+        Args:
+            keep_alive: Whether to configure SafariRemoteConnection to use
+                HTTP keep-alive. Defaults to True.
+            options: Instance of ``options.Options``.
+            service: Service object for handling the browser driver if you need to pass extra details
         """
         self.service = service if service else Service()
         options = options if options else Options()
