@@ -36,8 +36,11 @@ def _wrap_elements(result, ef_driver):
 
 
 class EventFiringWebDriver:
-    """A wrapper around an arbitrary WebDriver instance which supports firing
-    events."""
+    """Wrap an arbitrary WebDriver instance and support firing events.
+
+    This wrapper allows you to hook into various WebDriver events through an
+    AbstractEventListener implementation.
+    """
 
     def __init__(self, driver: WebDriver, event_listener: AbstractEventListener) -> None:
         """Creates a new instance of the EventFiringWebDriver.
@@ -74,10 +77,7 @@ class EventFiringWebDriver:
 
     @property
     def wrapped_driver(self) -> WebDriver:
-        """
-        Returns:
-            The WebDriver instance wrapped by this EventsFiringWebDriver.
-        """
+        """Returns the WebDriver instance wrapped by this EventsFiringWebDriver."""
         return self._driver
 
     def get(self, url: str) -> None:
@@ -172,10 +172,7 @@ class EventFiringWebElement:
 
     @property
     def wrapped_element(self) -> WebElement:
-        """
-        Returns:
-            The WebElement wrapped by this EventFiringWebElement instance.
-        """
+        """Returns the WebElement wrapped by this EventFiringWebElement instance."""
         return self._webelement
 
     def click(self) -> None:
