@@ -17,7 +17,6 @@
 
 import shutil
 from collections.abc import Mapping, Sequence
-from typing import Optional
 
 from selenium.webdriver.common import service
 
@@ -25,25 +24,28 @@ DEFAULT_EXECUTABLE_PATH = shutil.which("WPEWebDriver")
 
 
 class Service(service.Service):
-    """A Service class that is responsible for the starting and stopping of
-    `WPEWebDriver`.
+    """A Service class that is responsible for the starting and stopping of `WPEWebDriver`.
 
-    :param executable_path: install path of the WPEWebDriver executable, defaults to the first
-        `WPEWebDriver` in `$PATH`.
-    :param port: Port for the service to run on, defaults to 0 where the operating system will decide.
-    :param service_args: (Optional) Sequence of args to be passed to the subprocess when launching the executable.
-    :param log_output: (Optional) File path for the file to be opened and passed as the subprocess
-        stdout/stderr handler.
-    :param env: (Optional) Mapping of environment variables for the new process, defaults to `os.environ`.
+    Args:
+        executable_path: Install path of the WPEWebDriver executable, defaults
+            to the first `WPEWebDriver` in `$PATH`.
+        port: Port for the service to run on, defaults to 0 where the
+            operating system will decide.
+        service_args: (Optional) Sequence of args to be passed to the
+            subprocess when launching the executable.
+        log_output: (Optional) File path for the file to be opened and passed
+            as the subprocess stdout/stderr handler.
+        env: (Optional) Mapping of environment variables for the new process,
+            defaults to `os.environ`.
     """
 
     def __init__(
         self,
         executable_path: str = DEFAULT_EXECUTABLE_PATH,
         port: int = 0,
-        log_output: Optional[str] = None,
-        service_args: Optional[Sequence[str]] = None,
-        env: Optional[Mapping[str, str]] = None,
+        log_output: str | None = None,
+        service_args: Sequence[str] | None = None,
+        env: Mapping[str, str] | None = None,
         **kwargs,
     ):
         self._service_args = list(service_args or [])
@@ -61,6 +63,7 @@ class Service(service.Service):
 
     @property
     def service_args(self) -> Sequence[str]:
+        """Returns the sequence of service arguments."""
         return self._service_args
 
     @service_args.setter
