@@ -25,7 +25,7 @@ use crate::files::{create_parent_path_if_not_exists, create_path_if_not_exists};
 use fs2::FileExt;
 use std::fs;
 
-thread_local!(static LOCK_PATH: RefCell<Option<PathBuf>> = RefCell::new(None));
+thread_local!(static LOCK_PATH: RefCell<Option<PathBuf>> = const { RefCell::new(None) });
 
 const LOCK_FILE: &str = "sm.lock";
 
@@ -60,7 +60,7 @@ impl Lock {
 
     pub fn release(&mut self) {
         fs::remove_file(&self.path).unwrap_or_default();
-        self.file.unlock().unwrap_or_default();
+        FileExt::unlock(&self.file).unwrap_or_default();
         set_lock_path(None);
     }
 
@@ -70,12 +70,10 @@ impl Lock {
 }
 
 pub fn clear_lock_if_required() {
-    let lock_path = get_lock_path();
-    if lock_path.is_some() {
-        let lock = lock_path.unwrap();
-        if lock.exists() {
-            fs::remove_dir_all(lock.parent().unwrap()).unwrap_or_default();
-        }
+    if let Some(lock) = get_lock_path()
+        && lock.exists()
+    {
+        fs::remove_file(lock).unwrap_or_default();
     }
 }
 
